@@ -13,12 +13,9 @@ from sys import platform
 logging.getLogger(__name__)
 
 if platform == "linux" or platform == "linux2":
-    from src.ivanov.globals import java_linux as java
+    from ..globals import java_linux as java
 else:
-    from src.ivanov.globals import java_windows as java
-
-from src.ivanov.globals import hvac_url, hvac_token, hvac_secret_id, hvac_role_id, hvac_connections_path, \
-    hvac_connections_mountpoint, hvac_token_env_var, hvac_secret_env_var, hvac_role_id_env_var
+    from ..globals import java_windows as java
 
 
 def create_saspyconn(sasobjsp_host, sasobjsp_port, appserver, java=java):
