@@ -1,4 +1,4 @@
-from .core import AbstractSAS
+from .sas.core import AbstractSAS
 from .globals import sascs_sasobjsp_host, sascs_sasobjsp_port, sascs_alloved_appservers, \
     sasvs235_sasobjsp_host, sasvs235_sasobjsp_port, sasvs235_alloved_appservers, \
     sasvs221_sasobjsp_host, sasvs221_sasobjsp_port, sasvs221_alloved_appservers
